<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Price History Hyva Compatibility
 */

namespace Amasty\PriceHistoryHyva\Block;

use Amasty\PriceHistory\Block\ProductLowestPriceWrapper as PriceHistoryProductLowestPriceWrapper;
use Amasty\PriceHistory\Model\ConfigProvider;
use Amasty\PriceHistory\Model\Frontend\LowestPriceRenderer;
use Amasty\PriceHistory\Model\OptionSource\DisplayPrices;
use Magento\Framework\Registry;
use Magento\Framework\View\Element\Template;

class ProductLowestPriceWrapper extends PriceHistoryProductLowestPriceWrapper
{
    /**
     * @var ConfigProvider
     */
    private ConfigProvider $configProvider;

    /**
     * @var LowestPriceRenderer
     */
    private LowestPriceRenderer $lowestPriceRenderer;

    /**
     * @var Registry
     */
    private Registry $registry;

    public function __construct(
        Template\Context $context,
        ConfigProvider $configProvider,
        LowestPriceRenderer $lowestPriceRenderer,
        Registry $registry,
        array $data = []
    ) {
        parent::__construct($context, $configProvider, $lowestPriceRenderer, $registry, $data);
        $this->configProvider = $configProvider;
        $this->lowestPriceRenderer = $lowestPriceRenderer;
        $this->registry = $registry;
    }

    protected function _toHtml(): string
    {
        $product = $this->getProduct();

        if ($this->configProvider->getDisplayPrices() === DisplayPrices::NONE || !$product) {
            return '';
        }

        return $this->lowestPriceRenderer->render($product, parent::PRODUCT_PAGE_CLASS);
    }

    private function getProduct()
    {
        return $this->hasData('product')
            ? $this->getData('product')
            : $this->registry->registry('product');
    }
}
