<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Price History Hyva Compatibility
 */

namespace Amasty\PriceHistoryHyva\Plugin\ViewModel\ProductListItem;

use Amasty\PriceHistory\Model\ConfigProvider;
use Amasty\PriceHistory\Model\Frontend\LowestPriceRenderer;
use Amasty\PriceHistory\Model\OptionSource\DisplayPrices;
use Amasty\PriceHistory\Plugin\Catalog\Block\Product\ListProduct\AddLowestPrices;
use Hyva\Theme\Service\CurrentTheme;
use Hyva\Theme\ViewModel\ProductListItem;
use Magento\Catalog\Model\Product;

class AddPriceHistoryHtml
{
    /**
     * @var CurrentTheme
     */
    private CurrentTheme $currentTheme;

    /**
     * @var ConfigProvider
     */
    private ConfigProvider $configProvider;

    /**
     * @var LowestPriceRenderer
     */
    private LowestPriceRenderer $lowestPriceRenderer;

    public function __construct(
        CurrentTheme $currentTheme,
        ConfigProvider $configProvider,
        LowestPriceRenderer $lowestPriceRenderer
    ) {
        $this->currentTheme = $currentTheme;
        $this->configProvider = $configProvider;
        $this->lowestPriceRenderer = $lowestPriceRenderer;
    }

    /**
     * @param ProductListItem $subject
     * @param string $price
     * @return string
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function afterGetProductPriceHtml(ProductListItem $subject, string $price, Product $product): string
    {
        if (!$this->currentTheme->isHyva()) {
            return $price;
        }

        if ($this->configProvider->getDisplayPrices() === DisplayPrices::PRODUCT_AND_CATEGORY) {
            $price .= $this->lowestPriceRenderer->render($product, AddLowestPrices::CATEGORY_PAGE_CLASS);
        }

        return $price;
    }
}
